@@ -1,7 +1,7 @@
 from .client import Client
 from .datasource import Datasource, Record
 from .pipe import Pipe, PipeError, PipeJsonData, PipeJsonResponse, PipeMetadata, PipePageIterator
-from .query import OutputFormat, QueryError, SqlQuery
+from .query import OutputFormat, QueryError, SqlQuery, QueryJsonResult
 
 __all__ = [
     "Client",
@@ -16,4 +16,5 @@ __all__ = [
     "SqlQuery",
     "QueryError",
     "OutputFormat",
+    "QueryJsonResult",
 ]
